@@ -1,5 +1,5 @@
 -- hkt.hs: hOpenPGP key tool
--- Copyright © 2013-2018  Clint Adams
+-- Copyright © 2013-2019  Clint Adams
 --
 -- vim: softtabstop=4:shiftwidth=4:expandtab
 --
@@ -16,7 +16,6 @@
 -- You should have received a copy of the GNU Affero General Public License
 -- along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-{-# LANGUAGE CPP #-}
 {-# LANGUAGE DeriveGeneric #-}
 
 import HOpenPGP.Tools.Common (banner, versioner, warranty, keyMatchesFingerprint, keyMatchesEightOctetKeyId, keyMatchesUIDSubString)
@@ -27,9 +26,6 @@ import Codec.Encryption.OpenPGP.KeySelection (parseEightOctetKeyId, parseFingerp
 import Codec.Encryption.OpenPGP.Serialize ()
 import Codec.Encryption.OpenPGP.Signatures (verifyTKWith, verifySigWith, verifyAgainstKeyring)
 import Codec.Encryption.OpenPGP.Types
-#if !MIN_VERSION_base(4,8,0)
-import Control.Applicative ((<$>),(<*>), pure)
-#endif
 import Control.Applicative (optional, (<|>))
 import Control.Arrow ((&&&))
 import Control.Lens ((^.), _1, _2, (^..))
@@ -61,17 +57,11 @@ import Data.List (nub, sort)
 import Data.Map (Map)
 import qualified Data.Map as Map
 import Data.Maybe (fromMaybe, mapMaybe, listToMaybe)
-#if !MIN_VERSION_base(4,8,0)
-import Data.Monoid (mconcat)
-#endif
 import Data.Monoid ((<>))
 import Data.Text (Text)
 import qualified Data.Text as T
 import qualified Data.Text.Lazy.IO as TLIO
 import Data.Time.Clock.POSIX (getPOSIXTime, posixSecondsToUTCTime)
-#if !MIN_VERSION_base(4,8,0)
-import Data.Traversable (traverse)
-#endif
 import Data.Tuple (swap)
 import qualified Data.Yaml as Y
 import GHC.Generics
@@ -105,7 +95,6 @@ data Key = Key {
     keysize :: Maybe Int
   , keyalgo :: String
   , keyalgoabbreviation :: String
-  , keyid :: String
   , fpr :: String
 } deriving Generic
 
@@ -128,7 +117,6 @@ tkToTKey tk = TKey {
         mkey = Key <$> either (const Nothing) Just . pubkeySize . _pubkey
                    <*> show . _pkalgo
                    <*> pkalgoAbbrev . _pkalgo
-                   <*> either (const "unknown") (show . pretty) . eightOctetKeyID
                    <*> show . pretty . fingerprint
 
 showTKey :: TKey -> IO ()
@@ -138,7 +126,7 @@ showTKey key = putDoc $
     mconcat (map (\x -> pretty "sub  " <+> sizeabbrevkeyid x <> hardline) (subkeys key)) <>
     hardline
     where
-        sizeabbrevkeyid k = pretty (maybe "unknown" show (keysize k)) <> pretty (keyalgoabbreviation k) <> pretty "/0x" <> pretty (keyid k)
+        sizeabbrevkeyid k = pretty (maybe "unknown" show (keysize k)) <> pretty (keyalgoabbreviation k) <> pretty "/" <> pretty (fpr k)
 
 data Options = Options {
     keyring :: String
